Test whether a set of arcs are pairwise strictly disjoint.
disjointarcs( arcmat )disjointarcs() returns a logical - whether
the given arcs are pairwise strictly disjoint.
If 2 arcs overlap, or are abutting, the function returns FALSE.
an Nx2 matrix with an arc definition in each row;
so the total number of arcs is N.
The 1st number in the row is the center of the arc,
and the 2nd number is the length of the arc;
both in radians.
The length can be 0 or \(2\pi\),
defining the empty arc and the full circle respectively.
For these improper arcs, there must be only 1 row,
and the center is ignored.
plotarcs(),
complementaryarcs(),
arcsintersection(),
arcsunion(),
arcssymmdiff()