This section calculates the homeomorphism from the space of \(n\) or fewer arcs on the circle to the boundary of the polar zonoid, and its inverse. In this version of the package, \(n\) must be 0, 1, 2, or 3.
spherefromboundary( p )
boundaryfromsphere( x )spherefromboundary() returns
a unit vector in \(\mathbb{S}^{2n}\).
In case of error, the function returns NULL.
boundaryfromsphere() returns the computed point on the boundary of the zonoid.
Names are assigned indicating the corresponding term
in the trigonometric polynomial.
In case of error, the function returns NULL.
an vector of length \(2n{+}1\) on the boundary of
the polar zonoid in that dimension.
p can also be even-dimensional, and in that case \(\pi\)
is appended to make p odd-dimensional.
a non-zero vector of length \(2n{+}1\),
which is then unitized to put it on the sphere.
It can also be even-dimensional, and in that case 0
is appended to make x odd-dimensional.
spherefromboundary() is simply
central projection of the given point onto the unit sphere
centered at (0,0,...,0,0,\(\pi\)),
which is the center of the zonoid.
In this direction there is no restriction on \(n\).
boundaryfromsphere() is much harder.
One must find the intersection of two objects:
1) the ray based at the center of the zonoid in the direction x,
and 2) the boundary of the zonoid.
To do this, an implicit formula for the boundary has been
programmed, but only when
\(n\) is 0, 1, 2, or 3.
These two functions are inverses of each other.
spherefromarcs(),
arcsfromsphere(),
boundaryfromarcs(),
arcsfromboundary()