In each odd dimension is a special convex body - the polar zonoid - which is generated by trigonometric polynomials. The package has some applications of the polar zonoid, including the properties of spaces of arcs on the circle and 3x3 rotation matrices.
A zonoid is a special type of convex body, see Bolker. Among its many properties, a zonoid is centrally symmetric. A zonoid has many equivalent definitions, but in this package a zonoid \(Z\) in \(\mathbb{R}^m\) is defined by \(m\) real-valued functions \(f_1,f_2,...,f_m\) on the circle \(\mathbb{S}^1\). These functions are called the generators of \(Z\). When the generators are piecewise constant, one obtains a zonotope. For the precise definition of a zonoid, see the User Guide vignette.
For an integer \(n \ge 0\), we define the
polar zonoid \(Z_n \) by taking
the generators to be the \(2n{+}1\) functions:
$$\cos(\theta),\sin(\theta), \cos(2\theta),\sin(2\theta), ... ,\cos(n\theta),\sin(n\theta), 1 ~~~~~~~~ \theta \in [0,2\pi]$$
These functions are the standard basis of the trignometric polynomials. Note that it is convenient for us to put the constant function \(1\) last, instead of the usual convention of putting it first. The polar zonoid is a straighforward generalization of the polar zonohedron, see Chilton and Coxeter. In this paper, it is shown that as the number of sides of the polar zonohedron goes to \(\infty\), the zonohedron converges to \(Z_1 \subseteq \mathbb{R}^3\).
Let \(A_n\) be the space of \(n\) or fewer disjoint arcs in the circle. From properties of trigonometric polynomials, it can be shown that there is a natural homeomorphism \(A_n ~~ \rightleftarrows ~~ \partial Z_n\). For a proof of this, including the definition of the topology of \(A_n\), see the User Guide vignette. Among those properties is the fact that a trigonometric polynomial of degree \(n\) has at most \(2n\) roots. It is clear that \(2n\) roots define a set of \(n\) disjoint arcs, in two different ways.
In the special case \(n=0\), we define \(A_0\) to be the 2 improper arcs: the empty arc and the full circle. We have the inclusions: $$A_0 \subseteq A_1 \subseteq A_2 \subseteq ... \subseteq A_n $$
Now the boundary \(\partial Z_n\) is trivially homemorphic to the sphere \(\mathbb{S}^{2n}\). This is true for any convex body in \(\mathbb{R}^{2n+1}\). Thus we have homeomorphisms: $$A_n ~~ \rightleftarrows ~~ \partial Z_n ~~ \rightleftarrows ~~ \mathbb{S}^{2n} $$ where the symbol \(\rightleftarrows\) denotes a homeomorphism. The bulk of the API for this package is the numerical calculation of these maps. The maps that go from left to right are straightforward and implemented for all \(n\). The inverse maps are much more complicated and, in this version of the package, are only implemented for \(n = 0,1,2,3\). Since \(Z_n \) is determined by the single parameter \(n\), there is no need to have an object for \(Z_n\) in the package API. The parameter \(n\) can be inferred from the dimension of vector and matrix function arguments, or in some cases can be given explicitly.
As a sanity check, note that \(n\) arcs have \(2n\) endpoints, so we expect \(A_n\) to be a space of dimension \(2n\). The fact that it is a simple manifold like \(\mathbb{S}^{2n}\) is somewhat surprising. However, in the simple cases \(n\) = 0 and 1, it is easy to visualize; see the User Guide for details.
Glenn Davis <gdavis@gluonics.com>
Bolker, Ethan. A Class of Convex Bodies. Transactions of the American Mathematical Society. v. 145. Nov. 1969.
B. L. Chilton and H. S. M. Coxeter. Polar Zonohedra. The American Mathematical Monthly. Vol 70. No. 9. pp. 946-951. 1963.